@@ -134,6 +134,9 @@ pub struct Banner {
     /// represents Configuration.auto_bail
     auto_bail: BannerEntry,
 
+    /// represents Configuration.url_denylist
+    url_denylist: Vec<BannerEntry>,
+
     /// current version of feroxbuster
     pub(super) version: String,
 
@@ -146,6 +149,7 @@ impl Banner {
     /// Create a new Banner from a Configuration and live targets
     pub fn new(tgts: &[String], config: &Configuration) -> Self {
         let mut targets = Vec::new();
+        let mut url_denylist = Vec::new();
         let mut code_filters = Vec::new();
         let mut replay_codes = Vec::new();
         let mut headers = Vec::new();
@@ -160,6 +164,10 @@ impl Banner {
             targets.push(BannerEntry::new("🎯", "Target Url", target));
         }
 
+        for denied_url in &config.url_denylist {
+            url_denylist.push(BannerEntry::new("🚫", "Don't Scan", &denied_url));
+        }
+
         let mut codes = vec![];
         for code in &config.status_codes {
             codes.push(status_colorizer(&code.to_string()))
@@ -323,6 +331,7 @@ impl Banner {
             rate_limit,
             scan_limit,
             time_limit,
+            url_denylist,
             config: cfg,
             version: VERSION.to_string(),
             update_status: UpdateStatus::Unknown,
@@ -413,6 +422,10 @@ by Ben "epi" Risher {}                 ver: {}"#,
             writeln!(&mut writer, "{}", target)?;
         }
 
+        for denied_url in &self.url_denylist {
+            writeln!(&mut writer, "{}", denied_url)?;
+        }
+
         writeln!(&mut writer, "{}", self.threads)?;
         writeln!(&mut writer, "{}", self.wordlist)?;
         writeln!(&mut writer, "{}", self.status_codes)?;
